unit Main;

interface

uses
  Classes, StdCtrls, Controls, ExtCtrls, Forms,
  PrintSM, SMRAuto, Db, DBTables, ComCtrls, Grids, DBGrids, SMRALV;

type
  TfrmMain = class(TForm)
    rgSelectReport: TRadioGroup;
    dbMain: TDatabase;
    qryExample: TQuery;
    btnPreview: TButton;
    btnPrint: TButton;
    btnExit: TButton;
    smrAutoDBGrid: TSMPrintData;
    smrAutoText: TSMPrintText;
    lblLogo1: TLabel;
    lblLogo2: TLabel;
    lblLogo3: TLabel;
    lblLogo4: TLabel;
    lblLogo5: TLabel;
    rgLanguage: TRadioGroup;
    cbCustomPreview: TCheckBox;
    pcMode: TPageControl;
    tsDescription: TTabSheet;
    memoDescription: TMemo;
    tsDBGrid: TTabSheet;
    dSrc: TDataSource;
    DBGrid: TDBGrid;
    tsStringGrid: TTabSheet;
    smrAutoDataSet: TSMPrintData;
    smrAutoStringGrid: TSMPrintStringGrid;
    StringGrid: TStringGrid;
    smrAutoDSCalc: TSMPrintData;
    cbTwoColoring: TCheckBox;
    smrAutoListView: TSMPrintListView;
    tsListView: TTabSheet;
    ListView: TListView;
    procedure rgSelectReportClick(Sender: TObject);
    procedure btnPreviewClick(Sender: TObject);
    procedure btnExitClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure lblLogo4Click(Sender: TObject);
    procedure rgLanguageClick(Sender: TObject);
    procedure cbTwoColoringClick(Sender: TObject);
  private
    { Private declarations }
    function GetReport: TSMPrintBaseComponent;
    procedure CustomPreviewEvent(Sender: TObject);
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}
uses SysUtils, ShellAPI, Windows, CustPrev;

procedure TfrmMain.rgSelectReportClick(Sender: TObject);
var
  strPath: string;
  i, j: Integer;
begin
  strPath := ExtractFilePath(Application.ExeName);
  case rgSelectReport.ItemIndex of
    0: begin
         memoDescription.Lines.Assign(smrAutoDBGrid.SMProperty.Comments);
         qryExample.Open;
       end;
    1: begin
         memoDescription.Lines.Assign(smrAutoDataSet.SMProperty.Comments);
         qryExample.Open;
       end;
    2: begin
         memoDescription.Lines.Assign(smrAutoDataSet.SMProperty.Comments);
         qryExample.Open;
       end;
    3: begin
         memoDescription.Lines.Assign(smrAutoStringGrid.SMProperty.Comments);
         with StringGrid do
         begin
           ColCount := Random(100);
           RowCount := Random(100);
           if ColCount > 1 then
             FixedCols := 1;
           if RowCount > 1 then
             FixedRows := 1;
           for j := 0 to ColCount-1 do
           begin
             ColWidths[j] := Random(150);
             for i := 0 to RowCount-1 do
               Cells[j, i] := 'Random' + IntToStr(Random(10000));
           end;
         end;
       end;
    4: memoDescription.Lines.Assign(smrAutoText.SMProperty.Comments);
    5: begin
         memoDescription.Lines.Assign(smrAutoListView.SMProperty.Comments);
         with ListView do
         begin
           Columns.Clear;
           Items.Clear;
           for j := 0 to 5 + Random(10) do
             with Columns.Add do
             begin
               Caption := 'Column' + IntToStr(j);
               Width := 50 + Random(100)
             end;
           for i := 0 to 100 + Random(100) do
             with Items.Add do
             begin
               Caption := 'Item' + IntToStr(i);
               for j := 0 to Columns.Count-1 do
                 SubItems.Add('SubItem' + IntToStr(j));
             end;
         end
       end;

  end;
  tsDBGrid.TabVisible := (rgSelectReport.ItemIndex in [0, 1, 2]);
  tsStringGrid.TabVisible := (rgSelectReport.ItemIndex = 3);
  tsListView.TabVisible := (rgSelectReport.ItemIndex = 5);
  pcMode.ActivePage := tsDescription;
end;

procedure TfrmMain.btnPreviewClick(Sender: TObject);
begin
  with GetReport do
    case (Sender as TControl).Tag of
      2: begin
           if cbCustomPreview.Checked then
             OnPreview := CustomPreviewEvent
           else
             OnPreview := nil;
           Preview;
         end;
      3: Print;
    end;
//  qryExample.Close;
end;

procedure TfrmMain.btnExitClick(Sender: TObject);
begin
  Close
end;

procedure TfrmMain.FormActivate(Sender: TObject);
begin
  rgSelectReportClick(Sender)
end;

function TfrmMain.GetReport: TSMPrintBaseComponent;
begin
  case rgSelectReport.ItemIndex of
    1: Result := smrAutoDataSet;
    2: Result := smrAutoDSCalc;
    3: Result := smrAutoStringGrid;
    4: begin
         smrAutoText.FileName := '';
         Result := smrAutoText;
       end;
    5: Result := smrAutoListView;
  else//  0:
    Result := smrAutoDBGrid;
  end;
end;


procedure TfrmMain.lblLogo4Click(Sender: TObject);
begin
  ShellExecute(0, 'open', PChar((Sender as TLabel).Caption), nil, nil, SW_SHOWNORMAL);
end;

procedure TfrmMain.rgLanguageClick(Sender: TObject);
begin
  smrAutoDBGrid.Language.AutoDetect := (rgLanguage.ItemIndex < 1);
  smrAutoDataSet.Language.AutoDetect := smrAutoDBGrid.Language.AutoDetect;
  smrAutoDSCalc.Language.AutoDetect := smrAutoDBGrid.Language.AutoDetect;
  smrAutoStringGrid.Language.AutoDetect := smrAutoDBGrid.Language.AutoDetect;
  smrAutoText.Language.AutoDetect := smrAutoDBGrid.Language.AutoDetect;
  smrAutoListView.Language.AutoDetect := smrAutoDBGrid.Language.AutoDetect;

  if (rgLanguage.ItemIndex > 0) then
  begin
    smrAutoDBGrid.Language.LanguageID := TSMRLangID(rgLanguage.ItemIndex - 1);
    smrAutoDataSet.Language.LanguageID := smrAutoDBGrid.Language.LanguageID;
    smrAutoDSCalc.Language.LanguageID := smrAutoDBGrid.Language.LanguageID;
    smrAutoStringGrid.Language.LanguageID := smrAutoDBGrid.Language.LanguageID;
    smrAutoText.Language.LanguageID := smrAutoDBGrid.Language.LanguageID;
    smrAutoListView.Language.LanguageID := smrAutoDBGrid.Language.LanguageID;
  end
end;

procedure TfrmMain.CustomPreviewEvent(Sender: TObject);
begin
  with TfrmCustomPreview.Create(Application) do
  try
    SMRPreview.Report := (Sender as TSMPrintBaseComponent);
    ShowModal
  finally
    Free
  end;
end;

procedure TfrmMain.cbTwoColoringClick(Sender: TObject);
begin
  if cbTwoColoring.Checked then
    smrAutoDBGrid.Style.RowStyle := rsPriceList
  else
    smrAutoDBGrid.Style.RowStyle := rsNormal;
  smrAutoDataSet.Style.RowStyle := smrAutoDBGrid.Style.RowStyle;
  smrAutoDSCalc.Style.RowStyle := smrAutoDBGrid.Style.RowStyle;
  smrAutoStringGrid.Style.RowStyle := smrAutoDBGrid.Style.RowStyle;
  smrAutoText.Style.RowStyle := smrAutoDBGrid.Style.RowStyle;
  smrAutoListView.Style.RowStyle := smrAutoDBGrid.Style.RowStyle;
end;

end.
