unit CustPrev;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Menus, ExtCtrls, SMRView, Buttons, StdCtrls;

type
  TfrmCustomPreview = class(TForm)
    pnlButton: TPanel;
    MainMenu: TMainMenu;
    miFile: TMenuItem;
    miNavigation: TMenuItem;
    miHelp: TMenuItem;
    miFilePrint: TMenuItem;
    miFileSave: TMenuItem;
    miFileSeparator1: TMenuItem;
    miFileExit: TMenuItem;
    miNavigationFirstPage: TMenuItem;
    miNavigationPriorPage: TMenuItem;
    miNavigationNextPage: TMenuItem;
    miNavigationLastPage: TMenuItem;
    miNavigationSeparator1: TMenuItem;
    miNavigationFirstSheet: TMenuItem;
    miNavigationPriorSheet: TMenuItem;
    miNavigationNextSheet: TMenuItem;
    miNavigationLastSheet: TMenuItem;
    miView: TMenuItem;
    miViewZoomTo100: TMenuItem;
    miViewZoomToPageWidth: TMenuItem;
    miViewZoomToPageFit: TMenuItem;
    miHelpAbout: TMenuItem;
    SMRPreview: TSMRPreview;
    miOptions: TMenuItem;
    miOptionsShowMargins: TMenuItem;
    miOptionsShowGrid: TMenuItem;
    miOptionsSeparator1: TMenuItem;
    miOptionsZoomInByClick: TMenuItem;
    miOptionsZoomOutByClick: TMenuItem;
    miViewZoomCustom: TMenuItem;
    btnZoomToFit: TSpeedButton;
    btnZoomTo100: TSpeedButton;
    btnZoomToWidth: TSpeedButton;
    btnFirstPage: TSpeedButton;
    btnPrevPage: TSpeedButton;
    btnNextPage: TSpeedButton;
    btnLastPage: TSpeedButton;
    btnPrint: TSpeedButton;
    btnClose: TSpeedButton;
    lblNumPages: TLabel;
    procedure miHelpAboutClick(Sender: TObject);
    procedure miFileExitClick(Sender: TObject);
    procedure miFilePrintClick(Sender: TObject);
    procedure miFileSaveClick(Sender: TObject);
    procedure miViewZoomTo100Click(Sender: TObject);
    procedure miViewZoomToPageWidthClick(Sender: TObject);
    procedure miViewZoomToPageFitClick(Sender: TObject);
    procedure miNavigationLastPageClick(Sender: TObject);
    procedure miNavigationLastSheetClick(Sender: TObject);
    procedure miOptionsShowMarginsClick(Sender: TObject);
    procedure miOptionsShowGridClick(Sender: TObject);
    procedure miOptionsZoomInByClickClick(Sender: TObject);
    procedure SMRPreviewZoomChangeEvent(Sender: TObject);
    procedure SMRPreviewPageNumberChangeEvent(Sender: TObject);
    procedure SMRPreviewBarNumberChangeEvent(Sender: TObject);
    procedure FormActivate(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmCustomPreview: TfrmCustomPreview;

implementation

{$R *.DFM}
uses SMRCnst;

procedure TfrmCustomPreview.miHelpAboutClick(Sender: TObject);
begin
  SMRPreview.Report.About;
end;

procedure TfrmCustomPreview.miFileExitClick(Sender: TObject);
begin
  Close
end;

procedure TfrmCustomPreview.miFilePrintClick(Sender: TObject);
begin
  SMRPreview.Report.Print;
end;

procedure TfrmCustomPreview.miFileSaveClick(Sender: TObject);
var
  strFileName: string;
begin
  strFileName := '';
  SMRPreview.Report.SavePageToFile(strFileName);
end;

procedure TfrmCustomPreview.miViewZoomTo100Click(Sender: TObject);
begin
  SMRPreview.Zoom := 100;
end;

procedure TfrmCustomPreview.miViewZoomToPageWidthClick(Sender: TObject);
begin
  SMRPreview.Zoom := SMRPreview.GetZoomFitToWidth;
end;

procedure TfrmCustomPreview.miViewZoomToPageFitClick(Sender: TObject);
begin
  SMRPreview.Zoom := SMRPreview.GetZoomFitToPage;
end;

procedure TfrmCustomPreview.miNavigationLastPageClick(Sender: TObject);
begin
  case (Sender as TComponent).Tag of
    1: {first page} SMRPreview.PageNumber := 1;
    2: {prev page} SMRPreview.PageNumber := SMRPreview.PageNumber - 1;
    3: {next page} SMRPreview.PageNumber := SMRPreview.PageNumber + 1;
    4: {last page} SMRPreview.PageNumber := SMRPreview.Report.NumPages;
  end;
end;

procedure TfrmCustomPreview.miNavigationLastSheetClick(Sender: TObject);
begin
  case (Sender as TComponent).Tag of
    1: {first bar} SMRPreview.BarNumber := 1;
    2: {prev bar} SMRPreview.BarNumber := SMRPreview.BarNumber - 1;
    3: {next bar} SMRPreview.BarNumber := SMRPreview.BarNumber + 1;
    4: {last bar} SMRPreview.BarNumber := SMRPreview.Report.NumBars;
  end;
end;

procedure TfrmCustomPreview.miOptionsShowMarginsClick(Sender: TObject);
begin
  miOptionsShowMargins.Checked := not miOptionsShowMargins.Checked;
  SMRPreview.ShowMargins := miOptionsShowMargins.Checked;
end;

procedure TfrmCustomPreview.miOptionsShowGridClick(Sender: TObject);
begin
  miOptionsShowGrid.Checked := not miOptionsShowGrid.Checked;
  SMRPreview.ShowGrid := miOptionsShowGrid.Checked;
end;

procedure TfrmCustomPreview.miOptionsZoomInByClickClick(Sender: TObject);
begin
  (Sender as TMenuItem).Checked := True;
  if miOptionsZoomInByClick.Checked then
    SMRPreview.ZoomByClick := zcInc
  else
    SMRPreview.ZoomByClick := zcDec
end;

procedure TfrmCustomPreview.SMRPreviewZoomChangeEvent(Sender: TObject);
begin
  if SMRPreview.Zoom = 100 then
  begin
    miViewZoomTo100.Checked := True;
    btnZoomTo100.Down := True;
  end
  else
    if (SMRPreview.Zoom = SMRPreview.GetZoomFitToWidth) then
    begin
      miViewZoomToPageWidth.Checked := True;
      btnZoomToWidth.Down := True;
    end
    else
      if (SMRPreview.Zoom = SMRPreview.GetZoomFitToPage) then
      begin
        miViewZoomToPageFit.Checked := True;
        btnZoomToFit.Down := True;
      end
      else //custom
      begin
        miViewZoomCustom.Checked := True;

        btnZoomTo100.Down := False;
        btnZoomToWidth.Down := False;
        btnZoomToFit.Down := False;
      end;
end;

procedure TfrmCustomPreview.SMRPreviewPageNumberChangeEvent(
  Sender: TObject);
var intCount: Integer;
begin
  with SMRPreview.Report do
  begin
    intCount := NumPages;

    miNavigationFirstPage.Enabled := (intCurPage > -1);
    miNavigationPriorPage.Enabled := (intCurPage > 0);
    miNavigationNextPage.Enabled := (intCurPage < intCount-1);
    miNavigationLastPage.Enabled := (intCurPage < intCount);

{    btnFirstPage.Enabled := miNavigationFirstPage.Enabled;
    btnPrevPage.Enabled := miNavigationPriorPage.Enabled;
    btnNextPage.Enabled := miNavigationNextPage.Enabled;
    btnLastPage.Enabled := miNavigationLastPage.Enabled;
}
    lblNumPages.Caption := GetString(GetLanguageShift, smrcPreviewLblPages) +
                           ' ' + IntToStr(intCurPage+1) +
                           ' ' + GetString(GetLanguageShift, smrcPreviewLblOf) +
                           ' ' + IntToStr(NumPages);
  end;
end;

procedure TfrmCustomPreview.SMRPreviewBarNumberChangeEvent(
  Sender: TObject);
var intCount: Integer;
begin
  with SMRPreview.Report do
  begin
    intCount := NumBars;

    miNavigationFirstSheet.Enabled := (intCurBar > -1);
    miNavigationPriorSheet.Enabled := (intCurBar > 0);
    miNavigationNextSheet.Enabled := (intCurBar < intCount-1);
    miNavigationLastSheet.Enabled := (intCurbar < intCount);
  end;
end;

procedure TfrmCustomPreview.FormActivate(Sender: TObject);
var intCount: Integer;
begin
  SMRPreview.PageNumber := 1;
  SMRPreview.BarNumber := 1;

  with SMRPreview.Report do
  begin
    btnPrint.Hint := GetString(GetLanguageShift, smrcPreviewBtnPrint);

    btnZoomTo100.Hint := GetString(GetLanguageShift, smrcPreviewScale) + ' 100%';
    btnZoomToWidth.Hint := GetString(GetLanguageShift, smrcPreviewCbScale9);
    btnZoomToFit.Hint := GetString(GetLanguageShift, smrcPreviewCbScale10);

    btnClose.Hint := GetString(GetLanguageShift, smrcPreviewBtnClose);

    btnFirstPage.Hint := GetString(GetLanguageShift, smrcPreviewBtnFirstPage);
    btnPrevPage.Hint := GetString(GetLanguageShift, smrcPreviewBtnPrevPage);
    btnNextPage.Hint := GetString(GetLanguageShift, smrcPreviewBtnNextPage);
    btnLastPage.Hint := GetString(GetLanguageShift, smrcPreviewBtnLastPage);


    intCount := NumBars;

    if (intCount < 2) then
    begin
      miNavigationFirstSheet.Enabled := False;
      miNavigationPriorSheet.Enabled := False;
      miNavigationNextSheet.Enabled := False;
      miNavigationLastSheet.Enabled := False;
    end;
  end;
end;

end.
